@@ -64,15 +64,23 @@ center_on (GtkSourceGutterRenderer *renderer,
            gint                    *x,
            gint                    *y)
 {
-	GdkRectangle location;
 	GtkTextView *view;
+	GtkTextWindowType window_type;
+	GdkRectangle buffer_location;
+	gint window_y;
 
 	view = gtk_source_gutter_renderer_get_view (renderer);
+	window_type = gtk_source_gutter_renderer_get_window_type (renderer);
 
-	gtk_text_view_get_iter_location (view, iter, &location);
+	gtk_text_view_get_iter_location (view, iter, &buffer_location);
+
+	gtk_text_view_buffer_to_window_coords (view,
+					       window_type,
+					       0, buffer_location.y,
+					       NULL, &window_y);
 
 	*x = cell_area->x + (cell_area->width - width) * xalign;
-	*y = cell_area->y + (location.height - height) * yalign;
+	*y = window_y + (buffer_location.height - height) * yalign;
 }
 
 static void
@@ -386,7 +394,7 @@ gtk_source_gutter_renderer_pixbuf_new (void)
 /**
  * gtk_source_gutter_renderer_pixbuf_set_pixbuf:
  * @renderer: a #GtkSourceGutterRendererPixbuf
- * @pixbuf: (allow-none): the pixbuf
+ * @pixbuf: (nullable): the pixbuf, or %NULL.
  */
 void
 gtk_source_gutter_renderer_pixbuf_set_pixbuf (GtkSourceGutterRendererPixbuf *renderer,
@@ -419,7 +427,7 @@ gtk_source_gutter_renderer_pixbuf_get_pixbuf (GtkSourceGutterRendererPixbuf *ren
 /**
  * gtk_source_gutter_renderer_pixbuf_set_stock_id:
  * @renderer: a #GtkSourceGutterRendererPixbuf
- * @stock_id: (allow-none): the stock id
+ * @stock_id: (nullable): the stock id
  *
  * Deprecated: 3.10: Don't use this function.
  */
@@ -450,7 +458,7 @@ gtk_source_gutter_renderer_pixbuf_get_stock_id (GtkSourceGutterRendererPixbuf *r
 /**
  * gtk_source_gutter_renderer_pixbuf_set_gicon:
  * @renderer: a #GtkSourceGutterRendererPixbuf
- * @icon: (allow-none): the icon
+ * @icon: (nullable): the icon, or %NULL.
  */
 void
 gtk_source_gutter_renderer_pixbuf_set_gicon (GtkSourceGutterRendererPixbuf *renderer,
@@ -482,7 +490,7 @@ gtk_source_gutter_renderer_pixbuf_get_gicon (GtkSourceGutterRendererPixbuf *rend
 /**
  * gtk_source_gutter_renderer_pixbuf_set_icon_name:
  * @renderer: a #GtkSourceGutterRendererPixbuf
- * @icon_name: (allow-none): the icon name
+ * @icon_name: (nullable): the icon name, or %NULL.
  */
 void
 gtk_source_gutter_renderer_pixbuf_set_icon_name (GtkSourceGutterRendererPixbuf *renderer,
